@@ -1,14 +1,14 @@
-# Copyright 2013 SAP AG or an SAP affiliate company.
+# Copyright 2014 SAP AG or an SAP affiliate company.
 # 
 
-__version__ = '1.0.0'
+__version__ = '1.0.1'
 
 from sqlalchemy_sqlany import base
 
 # default dialect
 base.dialect = base.SQLAnyDialect
 
-from base import CHAR, VARCHAR, TIME, NCHAR, NVARCHAR,\
+from .base import CHAR, VARCHAR, TIME, NCHAR, NVARCHAR,\
                  TEXT, DATE, DATETIME, FLOAT, NUMERIC,\
                  BIGINT, INT, INTEGER, SMALLINT, BINARY,\
                  VARBINARY, UNITEXT, UNICHAR, UNIVARCHAR,\
